census_get_geographies: Get 2016 Census geographies and geographic attributes for a...

View source: R/census.R

census_get_geographiesR Documentation

Get 2016 Census geographies and geographic attributes for a geographic level.

Description

This function provides an interface to Statistics Canada's 2016 Census geographies Web Data Service (WDS) and returns the geographic identifiers (i.e., DGUIDs) for a geographic level. These DGUIDs are useful because you can use them to query StatsCan's other APIs to retrieve census data.

Please see StatsCan's website for more information:

Usage

census_get_geographies(geos = "DA", cpt = 35, lang = "E")

Arguments

geos

The geographic level to query. Defaults to "DA" for Dissemination Areas, but the following values are accepted:

  • CD = Census divisions

  • CMACA = Census metropolitan areas and census agglomerations

  • CSD = Census subdivisions (municipalities)

  • CT = Census tracts

  • DA = Dissemination areas

  • DPL = Designated places

  • ER = Economic regions

  • FED = Federal electoral districts (2013 Representation Order)

  • FSA = Forward sortation areas

  • HR = Health regions (including LHINs and PHUs)

  • POPCNTR = Population centres

  • PR = Canada, provinces and territories

cpt

One province or territory code. Defaults to "35" for Ontario, but the following values are accepted:

  • 00 = All provinces and territories

  • 10 = Newfoundland and Labrador

  • 11 = Prince Edward Island

  • 12 = Nova Scotia

  • 13 = New Brunswick

  • 24 = Quebec

  • 35 = Ontario

  • 46 = Manitoba

  • 47 = Saskatchewan

  • 48 = Alberta

  • 59 = British Columbia

  • 60 = Yukon

  • 61 = Northwest Territories

  • 62 = Nunavut

lang

The language in which to return results. There are two options:

  • E = English

  • F = French

Value

A tibble containing parsed API results.


Ottawa-Neighbourhood-Study/onsr documentation built on June 19, 2022, 11:46 a.m.