| census_get_geographies | R Documentation |
This function provides an interface to Statistics Canada's 2016 Census geographies Web Data Service (WDS) and returns the geographic identifiers (i.e., DGUIDs) for a geographic level. These DGUIDs are useful because you can use them to query StatsCan's other APIs to retrieve census data.
Please see StatsCan's website for more information:
census_get_geographies(geos = "DA", cpt = 35, lang = "E")
geos |
The geographic level to query. Defaults to "DA" for Dissemination Areas, but the following values are accepted:
|
cpt |
One province or territory code. Defaults to "35" for Ontario, but the following values are accepted:
|
lang |
The language in which to return results. There are two options:
|
A tibble containing parsed API results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.