| geocode_gmap | R Documentation |
Tidy Geocoding with Google's API
geocode_gmap(data, var, api_key = NA, verbose = FALSE, wait_nicely = TRUE)
data |
A dataframe containing a column with addresses stored as characters. |
var |
A column with addresses stored as characters. |
api_key |
A valid API key for Google Cloud Services. See https://cloud.google.com/free/ |
verbose |
Boolean flag controlling console updates. Defaults to FALSE. |
wait_nicely |
Boolean flag controlling API rate. Defaults to TRUE. |
The original dataframe with geocoded latitude and longitude in new columns lat and lng. Addresses that are invalid or not found return NA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.